@@ -73,6 +73,8 @@ class HiddenProducts(object):
             'plone.portlet.static',
             'plone.portlet.collection',
             'borg.localrole',
+            'plone.keyring',
+            'plone.protect',
             ]
 
 
