@@ -121,6 +121,7 @@ class QuickInstallerTool(UniqueObject, ObjectManager, SimpleItem):
     def getInstallMethod(self, productname):
         """ Return the installer method
         """
+        import_error_announced = False
         for mod, func in (('Install','install'),
                           ('Install','Install'),
                           ('install','install'),
@@ -139,7 +140,14 @@ class QuickInstallerTool(UniqueObject, ObjectManager, SimpleItem):
                                               'temp',
                                               productname+'.'+mod,
                                               func)
-                    except (ImportError, NotFound), e:
+                    except NotFound:
+                        continue
+                    except ImportError, e:
+                        if not import_error_announced:
+                            # do not announce the error 4 times
+                            import_error_announced = True
+                            msg = "%s, ImportError: %s" % (productname, str(e))
+                            logger.log(logging.ERROR, msg)
                         continue
                 except RuntimeError, msg:
                     # external method can throw a bunch of these
@@ -259,7 +267,8 @@ class QuickInstallerTool(UniqueObject, ObjectManager, SimpleItem):
                             'hasError':p.hasError()})
             else:
                 res.append({'id':r, 'title':name,'status':'new', 'hasError':False})
-        res.sort(lambda x,y: cmp(x.get('id',None),y.get('id',None)))
+        res.sort(lambda x,y: cmp(x.get('title', x.get('id', None)),
+                                 y.get('title', y.get('id', None))))
         return res
 
     security.declareProtected(ManagePortal, 'listInstalledProducts')
@@ -288,7 +297,8 @@ class QuickInstallerTool(UniqueObject, ObjectManager, SimpleItem):
                         'isLocked':p.isLocked(),
                         'isHidden':p.isHidden(),
                         'installedVersion':p.getInstalledVersion()})
-        res.sort(lambda x,y: cmp(x.get('id',None),y.get('id',None)))
+        res.sort(lambda x,y: cmp(x.get('title', x.get('id', None)),
+                                 y.get('title', y.get('id', None))))
         return res
 
     security.declareProtected(ManagePortal, 'getProductFile')
@@ -574,7 +584,7 @@ class QuickInstallerTool(UniqueObject, ObjectManager, SimpleItem):
                                   omitSnapshots=omitSnapshots)
             res +='ok:\n'
             if r:
-                r += str(r)+'\n'
+                res += str(r)+'\n'
         if REQUEST :
             REQUEST.RESPONSE.redirect(REQUEST['HTTP_REFERER'])
 
