@@ -7,7 +7,7 @@
  * Contributors see CREDITS.txt.
  *
  *****************************************************************************/
-// $Id: kupudrawers.js 52777 2008-03-20 15:05:56Z duncan $
+// $Id: kupudrawers.js 54915 2008-05-19 08:33:27Z duncan $
 
 function kupu_busy(ed) {
     if (ed.busy) ed.busy();
@@ -1463,7 +1463,10 @@ function ImageLibraryDrawer(tool, xsluri, libsuri, searchuri, baseelement, selec
         var sizeselector = document.getElementsByName('image-size-selector');
         if (sizeselector && sizeselector.length > 0) {
             sizeselector = sizeselector[0];
-            uri += sizeselector.options[sizeselector.selectedIndex].value;
+            var index = sizeselector.selectedIndex;
+            if (sizeselector.length > 0 && index >= 0) {
+                uri += sizeselector.options[index].value;
+            }
         }
         var radios = document.getElementsByName('image-align');
         var imgclass = "";
